==========================
 Invenio-Formatter v0.2.1
==========================

Invenio-Formatter v0.2.1 was released on August 25, 2015.

About
-----

Invenio module for formatting the bibliographic records.

*This is an experimental development preview release.*

Bug fixes
---------

- Adds missing `invenio_upgrader` dependency following its separation
  into standalone package.

- Fixes import of invenio_upgrader.

Installation
------------

   $ pip install invenio-formatter==0.2.1

Documentation
-------------

   http://invenio-formatter.readthedocs.org/en/v0.2.1

Happy hacking and thanks for flying Invenio-Formatter.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-formatter
|   URL: http://invenio-software.org
